lcvtoolbox.integrations.huggingface.mask.HuggingFaceMask
========================================================

.. currentmodule:: lcvtoolbox.integrations.huggingface.mask

.. autoclass:: HuggingFaceMask
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~HuggingFaceMask.__init__
      ~HuggingFaceMask.array_as_coco_rle
      ~HuggingFaceMask.as_array
      ~HuggingFaceMask.coco_rle_as_serializable
      ~HuggingFaceMask.create_bbox
      ~HuggingFaceMask.from_array
      ~HuggingFaceMask.from_coco_rle
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~HuggingFaceMask.bbox
      ~HuggingFaceMask.coco_rle
      ~HuggingFaceMask.width
      ~HuggingFaceMask.height
      ~HuggingFaceMask.encoded_rle
   
   